valigator
=========

.. epigraph::
    *Check your backups before you wreck yourself !*

|

.. image:: https://www.quantifiedcode.com/api/v1/project/6b2de325c287407aaf4998cf49c1c09e/badge.svg
  :target: https://www.quantifiedcode.com/app/project/6b2de325c287407aaf4998cf49c1c09e
  :alt: Code issues

|

| ``valigator`` helps you automate backup validation. It uses *Docker* to create ephemeral environments in which a backup restoration can occur.

| It aims to be a generic tool used to test **ANY** backup type:
| - Database backup (*mysql*, *mongodb*...)
| - ...


Installation
============

Requirements
------------

WIP

Setup
-----

Use ``pip`` to install it::

   $ pip install valigator

Usage
=====

WIP

Configuration
=============

WIP

Extensions
==========

WIP

Limitations
===========

This tool has been tested on the following OSes:

* Ubuntu 14.04

It has been tested against the following Python versions:

* Python 3.4
